AGW Logo

svn SVN Revision 69813 For aquabutton

This file contains the SVN revision history for aquabutton, at revision 69813.

Available information include commit date, the name of the committer, the file size, the SVN log messages and a diff from the previous version (if available).


file_info File Information

  • Commit Date: 17-Oct-2008 19:15:31 UTC
  • Committer: AG
  • File Size: 29775 byte(s)

svn_log Log Messages

The following log message was entered by the committer:

AquaButton: fix zero-sized bitmaps errors.


svn_diff Diff To Previous Version (69719)

Version SVN diff:

--- wxPython/3rdParty/AGW/agw/aquabutton.py 2011/11/09 21:31:32     69719
+++ wxPython/3rdParty/AGW/agw/aquabutton.py 2011/11/24 22:38:24     69813
@@ -2,7 +2,7 @@
# AQUABUTTON wxPython IMPLEMENTATION
#
# Andrea Gavana, @ 07 October 2008
# Latest Revision: 09 Nov 2011, 21.00 GMT
#
#
# TODO List
@@ -100,7 +100,7 @@

L{AquaButton} control is distributed under the wxPython license.

-Latest Revision: Andrea Gavana @ 09 Nov 2011, 21.00 GMT
+Latest Revision: Andrea Gavana @ 22 Nov 2011, 22.00 GMT

Version 0.4

@@ -345,7 +345,7 @@
# Save the bitmap using wx.MemoryDC for later use
self._saveBitmap = False
memory = wx.MemoryDC()
-            self._storedBitmap = wx.EmptyBitmapRGBA(width, height)
+            self._storedBitmap = wx.EmptyBitmapRGBA(max(width, 1), max(height, 1))
memory.SelectObject(self._storedBitmap)

gcMemory = wx.GraphicsContext.Create(memory)
@@ -1002,7 +1002,7 @@
# Save the bitmap using wx.MemoryDC for later use
self._saveBitmap = False
memory = wx.MemoryDC()
-            self._storedBitmap = wx.EmptyBitmapRGBA(width, height)
+            self._storedBitmap = wx.EmptyBitmapRGBA(max(width, 1), max(height, 1))
memory.SelectObject(self._storedBitmap)

gcMemory = wx.GraphicsContext.Create(memory)
@@ -2,7 +2,7 @@
#
# Andrea Gavana, @ 07 October 2008
-# Latest Revision: 09 Nov 2011, 21.00 GMT
+# Latest Revision: 24 Nov 2011, 22.00 GMT
#
#
Tree

Table Of Contents

Previous topic

SVN Revision 69719 For aquabutton

Next topic

artmanager